TransactionOptions

Struct TransactionOptions 

pub struct TransactionOptions {
    pub isolation_level: Option<TransactionIsolationLevel>,
}
Options for starting a VitrailTransaction through VitrailClient::begin_with_options(...).

The first transaction iteration intentionally keeps this type small and only exposes configuration that is meaningful for Postgres transaction startup.

Fields

isolation_level: Option<TransactionIsolationLevel>

Isolation level to apply when the transaction starts.

When this is None, Postgres uses the database default isolation level.

Implementations

Source

impl TransactionOptions

pub const fn new() -> TransactionOptions

Creates transaction options that use the database default isolation level.

pub const fn with_isolation_level( isolation_level: TransactionIsolationLevel, ) -> TransactionOptions

Creates transaction options with an explicit isolation level.