VitrailClient

Struct VitrailClient 

pub struct VitrailClient { /* private fields */ }
Postgres client entry point.

Implementations

Source

impl VitrailClient

pub async fn new(database_url: &str) -> Result<VitrailClient, Error>

pub async fn with_options( options: PoolOptions<Postgres>, database_url: &str, ) -> Result<VitrailClient, Error>

pub async fn begin(&self) -> Result<VitrailTransaction, Error>

Starts a new transaction using the database default isolation level.

The returned VitrailTransaction is an explicit transaction handle that can be passed through service layers and used with the same core query and write operations as VitrailClient.

pub async fn begin_with_options( &self, options: TransactionOptions, ) -> Result<VitrailTransaction, Error>

Starts a new transaction with explicit transaction options.

This is the entry point for configuring transaction startup behavior such as the isolation level.

pub async fn find_many<Q>( &self, query: Q, ) -> Result<Vec<<Q as QuerySpec>::Output>, Error>
where Q: QuerySpec,

pub async fn find_optional<Q>( &self, query: Q, ) -> Result<Option<<Q as QuerySpec>::Output>, Error>
where Q: QuerySpec,

pub async fn find_first<Q>( &self, query: Q, ) -> Result<<Q as QuerySpec>::Output, Error>
where Q: QuerySpec,

pub async fn insert<I>( &self, insert: I, ) -> Result<<I as InsertSpec>::Output, Error>
where I: InsertSpec,

pub async fn update_many<U>( &self, update: U, ) -> Result<<U as UpdateSpec>::Output, Error>
where U: UpdateSpec,

pub async fn delete_many<D>( &self, delete: D, ) -> Result<<D as DeleteSpec>::Output, Error>
where D: DeleteSpec,

pub async fn close(&self)